@@ -492,7 +492,7 @@ void jg_process_atexit(void)
 void jg_atexit(GVoidFunc func)
 {
 	g_static_mutex_lock (&atexit_lock);
-	atexit_list = g_slist_append(atexit_list, func);
+	atexit_list = g_slist_append(atexit_list, (gpointer) func);
 	g_static_mutex_unlock (&atexit_lock);
 }
 
