@@ -10,6 +10,7 @@
 #include <jni.h>
 #include <string.h>
 #include "jg_jnu.h"
+#include "org_gnu_glib_Struct.h"
 #ifdef __cplusplus
 extern "C" 
 {
@@ -26,7 +27,7 @@ JNIEXPORT jobject JNICALL Java_org_gnu_glib_Struct_getNullHandle
     return getHandleFromPointer(env, NULL);
 }
 
-JNIEXPORT jobject JNICALL Java_org_gnu_glib_Struct_init
+JNIEXPORT void JNICALL Java_org_gnu_glib_Struct_init
 (JNIEnv *env, jclass cls)
 {
 	g_atexit(jg_process_atexit);	    
