@@ -510,6 +510,7 @@ static jobject createNewBooleanInstance(JNIEnv *env, jboolean boolean_j)
     return (*env)->NewObject(env, booleanClass, constructor, boolean_j);
 }
 
+#define SIGNATURE_BUF_SIZE	64
 /*
  * Function used by Java_org_gnu_glib_Value_g_1value_1get_1java_1object
  * to return a java.lang.Enum object with the value enum_int
@@ -517,12 +518,12 @@ static jobject createNewBooleanInstance(JNIEnv *env, jboolean boolean_j)
 static jobject getEnumInstance(JNIEnv *env, GValue *value_g) 
 {
     char *enumClassName = javaobject_from_gtktype(G_VALUE_TYPE(value_g));
-    char *internSignature = g_malloc(64);
+    char internSignature[SIGNATURE_BUF_SIZE];
 
     jclass enumClass = (*env)->FindClass(env, enumClassName);
     if (enumClass == NULL)
         return (jobject) NULL;
-    sprintf(internSignature, "(I)L%s;", enumClassName);
+    g_snprintf(internSignature, SIGNATURE_BUF_SIZE, "(I)L%s;", enumClassName);
     jmethodID internMethod = (*env)->GetStaticMethodID(env, enumClass,
                                                        "intern", 
                                                        internSignature);
